@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 blocklistFile = '/home/user/MyDocs/BlockedCallers.txt'
-daemonFile = './callblocker-daemon.py'
-pidFile = './pid.txt'
+daemonFile = '/opt/pycallblocker/callblocker-daemon.py'
+pidFile = '/opt/pycallblocker/pid.txt'
 
 # Это все, что нам нужно для Qt
 from PyQt4 import QtGui, QtCore
